import { range, line, curveLinearClosed } from 'd3';

const gray = n => `rgb(${n},${n},${n})`;

const polyline = line()
  .x(d => d.x)
  .y(d => d.y)
  .curve(curveLinearClosed);

export const Star = ({ nodeNumber, skipFactor, radius, centerX, centerY }) => {
  console.log(nodeNumber)
  const data = range(nodeNumber).map(i => ({
    x: Math.sin((i / nodeNumber) * Math.PI * 2 * skipFactor) * radius,
    y: Math.cos((i / nodeNumber) * Math.PI * 2 * skipFactor) * radius
  }));

  const p1 = data[0];
  const p2 = data[1];
  const dx = p1.x - p2.x;
  const dy = p1.y - p2.y;
  const segmentLength = Math.sqrt(dx * dx + dy * dy);

  return (
    <g transform={`translate(${centerX},${centerY})`}>
      {data.map((d, i) => (
        <circle
          cx={d.x}
          cy={d.y}
          r={segmentLength}
          // fill={i === 7 ? "red":"none"}
          fill={'none'}
          stroke={gray(190)}
        />
      ))}
      {<path fill="none" stroke="#3866e9" strokeWidth={2} d={polyline(data)} />}
    </g>
  );
};
